body {
  padding-left: 3px;
  padding-right: 3px;
}

#table-of-contents, #main-text, #figure-list {
  position: absolute;
  height: 100%;
  overflow: auto;
  border-top: 1px solid #CCC;
  margin-top: 3px;
}

#table-of-contents {
  width: 220px;
  padding-top: 20px;
  border-left: 1px solid #CCC;
  border-right: 1px solid #CCC;
  margin-left: 3px;
}

#main-text {
  width: 450px;
  background: white;
  padding: 0px 50px 0px 20px;
  border-left: 1px solid #CCC;
  border-right: 1px solid #CCC;
  margin-left: 3px;
}

#figure-list {
  border-left: 1px solid #CCC;
  border-right: 1px solid #CCC;
  margin-right: 3px;
  margin-left: 3px;
}

#navbar {
  position: absolute;
  overflow: hidden;
  height: 25px;
  line-height: 25px;
  width: 100%;
  white-space: nowrap;
}

#toc-trigger {
  float: left;
  cursor: pointer;
  margin-right: 1em;
  margin-left: 0em;
  padding-top: 5px;
  padding-bottom: 5px;
  height: 15px;
}

#hamburger {
  width: 25px;
  height: 15px;
  background: linear-gradient(to bottom, black, black 20%, white 20%, white 40%, black 40%,
    black 60%, white 60%, white 80%, black 80%, black);
}

#navbar {
  border-bottom: 1px solid #CCC;
  padding-top: 10px;
  padding-bottom: 10px;
  padding-left: 20px;
  text-transform: uppercase;
  border-bottom: 1px solid #CCC;
  margin-top: 3px;
  margin-left: 3px;
  margin-right: 3px;
  padding-left: 20px;
  border-top: 1px solid #CCC;
  border-left: 1px solid #CCC;
  border-right: 1px solid #CCC;
}

body {
  font-family: Garamond, serif;
  letter-spacing: 0.05em;
  font-size: 16px;
  color: 0;
  line-height: 1.3em;
}

a, a:link, a:visited {
  color: #333;
  text-decoration: underline;
}

ul {
  list-style-type: dot;
}

h1, h2, h3, h4, h5, h6, h7 {
  font-family: Cardo, Palatino, serif;
  color: #333;
  letter-spacing: 0.1em;
  font-weight: 300;
  line-height: 1.1em;
  margin-top: 2em;
  margin-bottom: 0;
  text-transform: uppercase;
}

h1 {
  font-size: 27px;
  letter-spacing: 0.1em;
  margin-top: 100px;
  margin-bottom: 0em;
}

h2 {
  font-size: 20px;
  border-bottom: 1px solid #CCC;
}

h3, h4, h5, h6, h7 {
  font-size: 16px;
}

blockquote {
  border-left: 3px solid #DDD;
  margin-left: 0;
  padding-left: 2em;
  color: #888;
}

code {
  padding: 1px 4px;
}

pre {
  padding: 3px 20px;
}

code, pre {
  overflow: auto;
  background-color: #F9F9F9;
  border: 1px solid #DDD;
  border-radius: 3px;
  font-style: normal;
  color: #333;
  font-family: Courier, monospace;
  ;
font-size: 12px;
  line-height: 1.5em;
}

#table-of-contents {
  padding-left: 20px;
  padding-right: 50px;
  text-transform: uppercase;
  font-size: 12px;
}
#table-of-contents a {
  border: none;
  text-decoration: none;
}
#table-of-contents .toc h1, #table-of-contents .toc h2, #table-of-contents .toc h3,
#table-of-contents .toc h4, #table-of-contents .toc h5, #table-of-contents .toc h6,
#table-of-contents .toc h7 {
  line-height: 1.2em;
  border: none;
  text-transform: uppercase;
}
#table-of-contents .toc a h1 {
  border: none;
}
#table-of-contents .toc .active {
  text-decoration: underline;
  background-color: transparent;
}

#main-text a.figlink.active {
  background-color: #F0F0FF;
}
#main-text a.figlink.active:link, #main-text a.figlink.active:visited {
  color: #666;
}
#main-text .breadcrumb {
  margin-top: 0.5em;
  text-transform: uppercase;
  font-size: 12px;
}
#main-text .fig-in-text {
  font-style: italic;
  background-color: #F0F0FF;
  padding: 6px;
}
#main-text .fig-in-text pre, #main-text .fig-in-text code {
  border: 1px solid #CCE;
  background-color: #F0F0FF;
}
#main-text .fig-in-text code, #main-text .fig-in-text pre {
  letter-spacing: 0.05em;
}
#main-text .fig-in-text img {
  padding: 10px;
  width: 100%;
}
#main-text .timestamp {
  margin-top: 6em;
  text-align: right;
  border-top: 1px solid #CCC;
}

#figure-list {
  line-height: 1.2em;
  font-style: italic;
}
#figure-list code, #figure-list pre {
  letter-spacing: 0.05em;
}
#figure-list .fig-in-figlist {
  border-top: 1px solid #CCC;
  border-bottom: 1px solid #CCC;
  margin-top: 3px;
  margin-bottom: 3px;
  padding-left: 20px;
  padding-right: 50px;
}
#figure-list .active {
  background-color: #F0F0FF;
  color: #666;
}
#figure-list .active pre, #figure-list .active code {
  border: 1px solid #CCE;
  background-color: #F0F0FF;
}
#figure-list .reference {
  font-style: normal;
  font-size: 16px;
  margin-bottom: 0.4em;
  text-indent: -1em;
  margin-left: 1em;
}

@media screen and (max-width: 1200px) {
  h1 {
    margin-top: 2em;
  }
  h2 {
    font-size: 18px;
  }
  h3, h4, h5, h6, h7 {
    font-size: 14px;
  }
}

@media screen and (max-width: 480px) {
  h1 {
    margin-top: 2em;
  }
  h2 {
    font-size: 14px;
  }
  .fig-in-text {
    display: block;
  }
}
