#table-of-contents {
  border-right: 1px solid #CCC;
}

#main-text {
  border-right: 1px solid #CCC;
}

#navbar {
  border-bottom: 1px solid #CCC;
}

body {
  background-color: white;
  font-family: 'Helvetica Neue', Helvetica, sans-serif;
  font-size: 14px;
  line-height: 1.5em;
  letter-spacing: 0.05em;
  color: #333;
}

blockquote {
  border-left: 5px solid #888;
  margin-left: 0;
  padding-left: 2em;
  color: #888;
}

a, a:link, a:visited {
  text-decoration: none;
  color: #99B;
}

h1, h2, h3, h3, h4, h5, h6, h7 {
  font-size: 14px;
  text-transform: uppercase;
  color: #666;
  margin: 0;
  margin-top: 4em;
  margin-bottom: 0em;
  font-weight: normal;
  letter-spacing: 0.15em;
  line-height: 1.2em;
}

h1 {
  font-size: 24px;
  margin-top: 120px;
  margin-bottom: 10px;
}

h2 {
  font-size: 16px;
}

code {
  padding: 1px 4px;
}

pre {
  padding: 5px 20px;
}

code, pre {
  overflow: auto;
  background-color: #F9F9F9;
  border: 1px solid #DDD;
  border-radius: 5px;
  color: #888;
  font-size: 12px;
  line-height: 1.5em;
}

pre code {
  border: 0px;
}

.active {
  background-color: #EEF;
}

.fig-in-text {
  border-top: 1px solid #CCC;
  border-bottom: 1px solid #CCC;
}

#navbar {
  color: #666;
}

#table-of-contents {
  font-size: 12px;
  font-weight: normal;
  line-height: 1.5em;
  color: #666;
}
#table-of-contents a {
  text-decoration: none;
}
#table-of-contents a:link, #table-of-contents a:visited {
  color: #666;
}
#table-of-contents .toc h1, #table-of-contents .toc h2 {
  text-transform: uppercase;
  margin-top: 4px;
}
#table-of-contents .toc h3, #table-of-contents .toc h4, #table-of-contents .toc h5,
#table-of-contents .toc h6, #table-of-contents .toc h7 {
  font-style: italic;
}

#main-text a.figlink.active {
  padding: 4px 0px;
  margin-top: 6em;
  text-align: right;
}
#main-text a.figlink.active:link, #main-text a.figlink.active:visited {
  color: #99C;
  text-decoration: underline;
}
#main-text .fig-in-text {
  font-size: 12px;
  line-height: 1.2em;
  background-color: #EEF;
  color: #333;
}
#main-text .fig-in-text code, #main-text .fig-in-text pre {
  font-size: 12px;
  text-transform: none;
}
#main-text .fig-in-text img {
  padding-top: 10px;
}
#main-text .fig-in-text pre, #main-text .fig-in-text code {
  border: 1px solid #BBC;
  background-color: #E3E3FF;
  color: #666;
}

#figure-list .fig-in-figlist {
  font-size: 12px;
  line-height: 1.2em;
}
#figure-list .fig-in-figlist code, #figure-list .fig-in-figlist pre {
  font-size: 12px;
  text-transform: none;
}
#figure-list .fig-in-figlist img {
  padding-top: 10px;
}
#figure-list .fig-in-figlist.active {
  background-color: #EEF;
  color: #333;
}
#figure-list .fig-in-figlist.active pre, #figure-list .fig-in-figlist.active code {
  border: 1px solid #BBC;
  background-color: #E3E3FF;
  color: #666;
}
#figure-list .reference {
  font-size: 14px;
  line-height: 1.2em;
  margin-bottom: 0.4em;
  text-indent: -1em;
  margin-left: 1em;
}

@media (max-width: 480px) {
  h1 {
    font-size: 20px;
    margin-top: 60px;
  }
}
